cozy.types — cozy 1.1 documentation

# `cozy.types`

## Module Contents

### Functions

`register_type`(→ angr.sim_type.SimType) | Parses a C-style type definition given in the input string, assuming the given architecture. Registers this type with angr.
`register_types`(→ angr.sim_type.SimType) | Parses a series of type definition given in the input string. Registers this type with angr.

cozy.types.register_type(type_definition: str, arch: archinfo.Arch) → angr.sim_type.SimType

  Parses a C-style type definition given in the input string, assuming the given architecture. Registers this type with angr.

  Parameters:

    - type_definition (str) – The type definition, given in C-style format.

    - arch (Arch) – The architecture this type should be used with.

  Returns:

    The parsed typed.

  Return type:

    SimType

cozy.types.register_types(type_definition: str) → angr.sim_type.SimType

  Parses a series of type definition given in the input string. Registers this type with angr.

  Parameters:

    - type_definition (str) – The type definition, given in C-style format.

    - arch (Arch) – The architecture this type should be used with.

  Returns:

    The parsed typed.

  Return type:

    SimType